[otrs-cvs] otrs/Kernel/Modules AgentTicketProcess.pm,1.36,1.37

"CVS commits notifications of OTRS.org" <[email protected]>
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/otrs/Kernel/Modules
In directory lancelot:/tmp/cvs-serv32278/Kernel/Modules

Modified Files:
	AgentTicketProcess.pm 
Log Message:
QA follow-up for bug#9111 - ProcessManagement: Empty Service or SLA causes an error.

Author: cr

Index: AgentTicketProcess.pm
===================================================================
RCS file: /home/cvs/otrs/Kernel/Modules/AgentTicketProcess.pm,v
retrieving revision 1.36
retrieving revision 1.37
diff -2 -u -d -r1.36 -r1.37
--- AgentTicketProcess.pm	31 Jan 2013 21:47:02 -0000	1.36
+++ AgentTicketProcess.pm	1 Feb 2013 18:42:01 -0000	1.37
@@ -319,5 +319,5 @@
     # is used for:
     # - Parameter checking before storing
-    # - will be used for ACL checking lateron
+    # - will be used for ACL checking later on
     my $GetParam = $Self->_GetParam(
         ProcessEntityID => $ProcessEntityID,
@@ -598,5 +598,5 @@
             $Services = $Data;
 
             # add Service to the JSONCollector
             push(
                 @JSONCollector,
@@ -604,5 +604,5 @@
                     Name         => $Self->{NameToID}{$CurrentField},
                     Data         => $Data,
-                    SelectedID   => $Param{GetParam}{ $Self->{NameToID}{$CurrentField} },
+                    SelectedID   => $Self->{ParamObject}->GetParam( Param => 'ServiceID' ) || '',
                     PossibleNone => 1,
                     Translation  => 0,
@@ -619,7 +619,8 @@
                 %{ $Param{GetParam} },
                 Services => $Services,
+                ServiceID => $Self->{ParamObject}->GetParam( Param => 'ServiceID' ) || '',
             );
 
-            # add SLA to the JSONCollector
+            # add SLA to the JSONCollector (Use SelectedID from web request)
             push(
                 @JSONCollector,
@@ -627,5 +628,5 @@
                     Name         => $Self->{NameToID}{$CurrentField},
                     Data         => $Data,
-                    SelectedID   => $Param{GetParam}{ $Self->{NameToID}{$CurrentField} },
+                    SelectedID   => $Self->{ParamObject}->GetParam( Param => 'SLAID' ) || '',
                     PossibleNone => 1,
                     Translation  => 0,
---------------------------------------------------------------------
@@ -598,5 +598,5 @@
             $Services = $Data;
 
-            # add Service to the JSONCollector
+            # add Service to the JSONCollector (Use ServiceID from web request)
             push(
                 @JSONCollector,
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.